#ps1_sysnative

$ErrorActionPreference = 'Stop'

$modulePath = "heat-powershell-utils.psm1"
$currentLocation = Split-Path -Parent $MyInvocation.MyCommand.Path
$fullPath = Join-Path $currentLocation $modulePath
Import-Module -Name $fullPath -DisableNameChecking -Force

# This is the code that used to live in the Ops Station yaml that does the bulk of th configuration for the Windows box
function Setup-Server () {
    
    $RebootCode = $true
    $ErrorActionPreference = 'SilentlyContinue'
    Set-ExecutionPolicy -ExecutionPolicy Unrestricted -Force

    #----Turn off Firewall
    Set-NetFirewallProfile -Profile Domain,Public,Private -Enabled False
    Set-NetFirewallRule -DisplayGroup "Network Discovery" -Enabled True
    Set-NetFirewallRule -DisplayGroup "remote desktop" -Enabled True
    
    #----Enable SSH
    Add-WindowsCapability -Online -Name OpenSSH.Server~~~~0.0.1.0
    Start-Service sshd
    Set-Service -Name sshd -StartupType Automatic

    #----Disable Windows Updates
    set-service wuauserv -startuptype disabled
    stop-service wuauserv

    #----Update PowerShell Help
    Update-Help -Force

    #----Turn off Windows Defender
    New-Item -path 'HKLM:\SOFTWARE\Policies\Microsoft\Windows Defender\Real-Time Protection'
    New-ItemProperty -path 'HKLM:\SOFTWARE\Policies\Microsoft\Windows Defender\Real-Time Protection'-Name 'DisableRealtimeMonitoring' -Type Dword -Value 1
    set-ItemProperty -Path 'HKLM:\Software\Microsoft\Windows\CurrentVersion\Policies\System' -name "dontdisplaylastusername" -Value 1

    #----Disable OOBE Network Discovery
    Set-NetConnectionProfile -Name "*" -NetworkCategory Private

    #----Create User <lastname>, password set to password, add to admin group
    New-LocalUser -Name "$user" -Password (ConvertTo-SecureString -AsPlaintext -String "$pass" -Force)
    Add-LocalGroupMember -Group "Administrators" -Member "$user"
    Add-LocalGroupMember -Group "Remote Desktop Users" -Member "$user"

    #----Disable Default Admin Accounts
    Disable-LocalUser -Name "administrator"
    Disable-LocalUser -Name "admin"

    #----Rename computer
    Rename-computer -newname "WinOpsStation"

    #----Set TimeZone to EST
    Set-TimeZone "Eastern Standard Time" 

    #-----Reboot after setup is complete
    ExitFrom-Script -ExitCode $RebootCode

}

# Pulled this out of the base config function so that test stacks didn't take as long to boot up
function Install-Software () {
    
    $RebootCode = $true
    $ErrorActionPreference = 'SilentlyContinue'
    #----Downloads and installs Google Chrome
    Invoke-WebRequest -Uri "http://dl.google.com/chrome/install/375.126/chrome_installer.exe" -Outfile "C:\chrome_installer.exe"
    & "C:\chrome_installer.exe" /silent /install         

    #-----install choco
    Set-ExecutionPolicy Bypass -Scope Process -Force
    iex ((New-Object System.Net.WebClient).DownloadString('https://chocolatey.org/install.ps1'))

    #-----Install tightvnc as service with regular connection and view only connection
    choco install tightvnc -y --installArguments 'SERVER_REGISTER_AS_SERVICe=1 SET_ACCEPTRFBCONNECTIONS=1 VALUE_OF_ACCEPTRFBCONNECTIONS=1 SET_ALWAYSSHARED=1 VALUE_OF_ALWAYSSHARED=1 SET_DISCONNECTACTION=+1 VALUE_OF_DISCONNECTACTION=1 SET_USECONTROLAUTHENTICATION=1 VALUE_OF_USECONTROLAUTHENTICATION=1 SET_USEVNCAUTHENTICATION=1 VALUE_OF_USEVNCAUTHENTICATION=1  SET_CONTROLPASSWORD=1 VALUE_OF_CONTROLPASSWORD=$pass SET_PASSWORD=1 VALUE_OF_PASSWORD=$vncpass SET_VIEWONLYPASSWORD=1 VALUE_OF_VIEWONLYPASSWORD=$vncviewpass'
    
    #-----Reboot after setup is complete
    ExitFrom-Script -ExitCode $RebootCode
}

function Initialize-Server ($parameters) {
    Setup-Server
    #Install-Software
    $successMessage = "Finished Windows Ops Station Setup"
    Send-HeatWaitSignal -Endpoint $parameters['ENDPOINT'] `
                        -Message $successMessage `
                        -Success $true `
                        -Token $parameters['TOKEN']
}


# ----- REFERENCE FOR POTENTIAL FUTURE USE ----- #
# function Initialize-Server ($parameters) {
#     try {
#         LogTo-File "Spinning up Windows Ops Station"

#         Setup-Server

#         $successMessage = "Finished Windows Ops Station Setup"
#         LogTo-File $successMessage
#         Send-HeatWaitSignal -Endpoint $parameters['ENDPOINT'] `
#                             -Message $successMessage `
#                             -Success $true `
#                             -Token $parameters['TOKEN']
#     } catch {
#         $failMessage = "Failed to Setup Windows Ops Station"
#         LogTo-File $failMessage
#         LogTo-File "Exception details: $_.Exception.Message"

#         Send-HeatWaitSignal -Endpoint $parameters['ENDPOINT'] `
#                             -Message $_.Exception.Message `
#                             -Success $false `
#                             -Token $parameters['TOKEN']
#     }
# }

Export-ModuleMember -Function *
