#!/bin/bash
DEBIAN_FRONTEND=noninteractive

pkg_array=({bison,build-essential,checkinstall,curl,dirmngr,docker,docker-compose,dnsutils,ethtool,firefox,flex,ftp,gcc,gdebi,gdb,git,gvfs-bin,install,iptables-dev,libdumbnet-dev,libnet1-dev,libnetfilter-queue-dev,libpcap-dev,libpcre3-dev,libqt5scripttools5,libqt5webkit5,libssl1.0.0,locate,lsof,make,netcat,nginx,nmap,openvpn,p0f,proftpd,proxychains,pv,python3,python3-pip,python-pip,software-properties-common,scapy,tcpdump,telnet,terminator,tigervnc-standalone-server,tmux,traceroute,wireshark,xrdp,zlib1g-dev})
for x in ${pkg_array[@]}; do apt-get install -y $x; done

# Modify wireshark to run for non-root users
echo "wireshark-common wireshark-common/install-setuid boolean true" | debconf-set-selections
DEBIAN_FRONTEND=noninteractive dpkg-reconfigure wireshark-common

# Change permissions for dumpcap to support interfaces with wireshark no permissions
chmod 777 /usr/bin/dumpcap


# ----- Makes rdp work with VNC by default
cd /etc/xrdp
cat <<__EOF__ | sudo patch -p1
--- a/xrdp.ini     2017-06-19 14:05:53.290490260 +0900
+++ b/xrdp.ini  2017-06-19 14:11:17.788557402 +0900
@@ -147,15 +147,6 @@ tcutils=true
 ; Session types
 ;

-[Xorg]
-name=Xorg
-lib=libxup.so
-username=ask
-password=ask
-ip=127.0.0.1
-port=-1
-code=20
-
 [Xvnc]
 name=Xvnc
 lib=libvnc.so
@@ -166,6 +157,15 @@ port=-1
 #xserverbpp=24
 #delay_ms=2000

+[Xorg]
+name=Xorg
+lib=libxup.so
+username=ask
+password=ask
+ip=127.0.0.1
+port=-1
+code=20
+
 [console]
 name=console
 lib=libvnc.so
__EOF__
sudo systemctl restart xrdp

# Create directories, alter permissions, and add student resource files
mkdir /home/activity_resources/
mkdir /home/activity_resources/pcaps
cd /home/activity_resources/pcaps
wget https://git.cybbh.space/net/public/raw/master/modules/networking/activities/resources/anomaly_detection1.pcap
wget https://git.cybbh.space/net/public/raw/master/modules/networking/activities/resources/anomaly_detection2.pcap
wget https://git.cybbh.space/net/public/raw/master/modules/networking/activities/resources/anomaly_detection3.pcap
wget https://git.cybbh.space/net/public/raw/master/modules/networking/activities/resources/ids.pcap
wget https://git.cybbh.space/net/public/raw/master/modules/networking/activities/resources/practice.pcap
wget https://git.cybbh.space/net/public/raw/master/modules/networking/activities/resources/remote_capture.pcap
chmod -R 777 /home/activity_resources

# Download and install snort for Networking IDS Activity
cd /usr/share/cctc
wget https://git.cybbh.space/net/public/raw/master/modules/networking/heat/packages_and_scripts/daq_2.0.6-1_amd64.deb
wget https://git.cybbh.space/net/public/raw/master/modules/networking/heat/packages_and_scripts/snort_2.9.9.0-1_amd64.deb
gdebi --non-interactive "daq_2.0.6-1_amd64.deb"
gdebi --non-interactive "snort_2.9.9.0-1_amd64.deb"
mkdir /etc/snort
mkdir /etc/snort/rules
mkdir /var/log/snort
ldconfig
cd /etc/snort
touch snort.conf
echo "include /etc/snort/rules/icmp.rules" >> snort.conf
cd rules
touch icmp.rules
echo "alert icmp any any -> any any (msg:"ICMP detected"; sid:111; rev:1;)" >> icmp.rules
cd

# ----- Replace web server default index page
rm /var/www/html/*
echo "This is the default webpage for the Linux OpStation" >/var/www/html/index.html


# ----- Disable TCP Offloading
cat <<__EOF__ > /etc/network/if-up.d/tcpoffload
#!/bin/bash
/sbin/ethtool -K eth0 tx off sg off tso off
__EOF__
chmod +x /etc/network/if-up.d/tcpoffload
cd /etc/network/if-up.d/
./tcpoffload
